@@ -3,17 +3,20 @@
     lets
     ~~~~
 
-    Several :class:`gevent.Greenlet` subclasses.
+    Utilities for gevent_ 1.0.
+
+    .. _gevent: http://gevent.org/
 
     :copyright: (c) 2013 by Heungsub Lee
     :license: BSD, see LICENSE for more details.
 """
 from __future__ import absolute_import
 
+from .objectpool import ObjectPool
 from .processlet import Processlet, ProcessExit, ProcessPool
 from .transparentlet import Transparentlet, TransparentGroup
 
 
-__version__ = '0.0.8'
-__all__ = ['Processlet', 'ProcessExit', 'ProcessPool',
+__version__ = '0.0.9'
+__all__ = ['ObjectPool', 'Processlet', 'ProcessExit', 'ProcessPool',
            'Transparentlet', 'TransparentGroup']
